package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Feb 6, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package errors provides internal error handlign routines.
Wrap is function to propagate error to upper levels.
type Causer interface {
Cause() error
}
Causer returns the cause of the error.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.